@@ -33,7 +33,7 @@ my($graph)  = GraphViz2 -> new
 	 global => {directed => 1},
 	 graph  => {rankdir => 'TB'},
 	 logger => $logger,
-	 node   => {color => 'darkblue', shape => 'oval'},
+	 node   => {color => 'blue', shape => 'oval'},
 	);
 my($g) = GraphViz2::Parse::Regexp -> new(graph => $graph);
 
